==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/he-IL/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'שדות מותאמים אישית',
    'manage'                    => 'Manage',
    'field'		                => 'שדה',
    'about_fieldsets_title'		=> 'אודות שדות',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'הצפן את הערך של שדה זה במסד הנתונים',
    'encrypt_field_help'      => 'אזהרה: הצפנת שדה הופכת אותו לבלתי ניתן לחיפוש.',
    'encrypted'      	        => 'מוצפן',
    'fieldset'      	        => 'קבוצת שדות',
    'qty_fields'      	      => 'Qty שדות',
    'fieldsets'      	        => 'שדות',
    'fieldset_name'           => 'שם שדה',
    'field_name'              => 'שם שדה',
    'field_values'            => 'ערכי שדות',
    'field_values_help'       => 'הוסף אפשרויות לבחירה, אחת בכל שורה. קווים ריקים שאינם השורה הראשונה יתעלמו.',
    'field_element'           => 'אלמנט טופס',
    'field_element_short'     => 'אֵלֵמֶנט',
    'field_format'            => 'פוּרמָט',
    'field_custom_format'     => 'פורמט מותאם אישית',
    'field_custom_format_help'     => 'This field allows you to use a regex expression for validation. It should start with "regex:" - for example, to validate that a custom field value contains a valid IMEI (15 numeric digits), you would use <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'נדרש',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'דגמים משומשים',
    'order'   		            => 'להזמין',
    'create_fieldset'         => 'שדה חדש',
    'update_fieldset'         => 'Update Fieldset',
    'fieldset_does_not_exist'   => 'Fieldset :id does not exist',
    'fieldset_updated'         => 'Fieldset updated',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'שדה מותאם אישית חדש',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'הערך של שדה זה מוצפן במסד הנתונים. רק משתמשי מנהל יוכלו להציג את הערך המפוענח',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails',
    'show_in_email_short'     => 'Include in emails.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'הוסף שדה למערך',
    'make_optional' => 'חובה - בחר כדי להפוך לאופציונלי',
    'make_required' => 'אופציונלי - בחר כדי להפוך לחובה',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code>:db_column</code> but should be <code>:expected</code>.',
    'is_unique' => 'ערך זה חייב להיות ייחודי בכל הנכסים',
    'unique' => 'ייחודי',
    'display_in_user_view' => 'Allow the checked out user to view these values in their View Assigned Assets page',
    'display_in_user_view_table' => 'Visible to User',
    'auto_add_to_fieldsets' => 'Automatically add this to every new fieldset',
    'add_to_preexisting_fieldsets' => 'Add to any existing fieldsets',
    'show_in_listview' => 'הצגה בתצוגות רשימה כברירת מחדל. משתמשים מורשים עדיין יוכלו להציג/להסתיר את בורר העמודות',
    'show_in_listview_short' => 'הצגה ברשימות',
    'show_in_requestable_list_short' => 'Show in requestable assets list',
    'show_in_requestable_list' => 'Show value in requestable assets list. Encrypted fields will not be shown',
    'encrypted_options' => 'This field is encrypted, so some display options will not be available.',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/he-IL/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'שדות מותאמים אישית',
    'manage'                    => 'Manage',
    'field'		                => 'שדה',
    'about_fieldsets_title'		=> 'אודות שדות',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'הצפן את הערך של שדה זה במסד הנתונים',
    'encrypt_field_help'      => 'אזהרה: הצפנת שדה הופכת אותו לבלתי ניתן לחיפוש.',
    'encrypted'      	        => 'מוצפן',
    'fieldset'      	        => 'קבוצת שדות',
    'qty_fields'      	      => 'Qty שדות',
    'fieldsets'      	        => 'שדות',
    'fieldset_name'           => 'שם שדה',
    'field_name'              => 'שם שדה',
    'field_values'            => 'ערכי שדות',
    'field_values_help'       => 'הוסף אפשרויות לבחירה, אחת בכל שורה. קווים ריקים שאינם השורה הראשונה יתעלמו.',
    'field_element'           => 'אלמנט טופס',
    'field_element_short'     => 'אֵלֵמֶנט',
    'field_format'            => 'פוּרמָט',
    'field_custom_format'     => 'פורמט מותאם אישית',
    'field_custom_format_help'     => 'This field allows you to use a regex expression for validation. It should start with "regex:" - for example, to validate that a custom field value contains a valid IMEI (15 numeric digits), you would use <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'נדרש',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'דגמים משומשים',
    'order'   		            => 'להזמין',
    'create_fieldset'         => 'שדה חדש',
    'update_fieldset'         => 'Update Fieldset',
    'fieldset_does_not_exist'   => 'Fieldset :id does not exist',
    'fieldset_updated'         => 'Fieldset updated',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'שדה מותאם אישית חדש',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'הערך של שדה זה מוצפן במסד הנתונים. רק משתמשי מנהל יוכלו להציג את הערך המפוענח',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails',
    'show_in_email_short' => 'Include in emails',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'הוסף שדה למערך',
    'make_optional' => 'חובה - בחר כדי להפוך לאופציונלי',
    'make_required' => 'אופציונלי - בחר כדי להפוך לחובה',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code>:db_column</code> but should be <code>:expected</code>.',
    'is_unique' => 'ערך זה חייב להיות ייחודי בכל הנכסים',
    'unique' => 'ייחודי',
    'display_in_user_view' => 'Allow the checked out user to view these values in their View Assigned Assets page',
    'display_in_user_view_table' => 'Visible to User',
    'auto_add_to_fieldsets' => 'Automatically add this to every new fieldset',
    'add_to_preexisting_fieldsets' => 'Add to any existing fieldsets',
    'show_in_listview' => 'הצגה בתצוגות רשימה כברירת מחדל. משתמשים מורשים עדיין יוכלו להציג/להסתיר את בורר העמודות',
    'show_in_listview_short' => 'הצגה ברשימות',
    'show_in_requestable_list_short' => 'Show in requestable assets list',
    'show_in_requestable_list' => 'Show value in requestable assets list. Encrypted fields will not be shown',
    'encrypted_options' => 'This field is encrypted, so some display options will not be available.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];
